==> sapdb-source-7.3.00.48.tgz: V73_00_48/SAPDB_ORG/sys/src/wd/vwd10mem.c <==
/*!**********************************************************************

  module: vwd10mem.c

  -----------------------------------------------------------------------

  
  responsible:  Holger Bischoff
				Markus Oezgen

  special area: WebAgent

  description:  Memory routines for WebAgent

  see also:

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/

#include <stdlib.h>

#ifdef WIN32
#define _DEBUG
#include <crtdbg.h>
#endif

#include "geo102.h"
#include "hwd10mem.h"

static wd11AllocCount = 0;

void sapdbwa_allocat( sapdbwa_Int4        lSize,
					  sapdbwa_UInt1		**ppucObjPtr,
					  tsp00_BoolAddr      pbOk		)
{
    wd11AllocCount++;
    *ppucObjPtr = malloc( lSize );
    *pbOk = (tsp00_Bool) (ppucObjPtr != NULL);
}


void sapdbwa_reallocat( sapdbwa_Int4      lSize,
						sapdbwa_UInt1	**ppucObjPtr,
						tsp00_BoolAddr    pbOk		)
{
    *ppucObjPtr = realloc( *ppucObjPtr, lSize );
    *pbOk = (tsp00_Bool) (ppucObjPtr != NULL);
}


void sapdbwa_free( sapdbwa_UInt1*  pucObjPtr )
{
    tsp00_Bool dump = (pucObjPtr == (sapdbwa_UInt1*) 17);
    
    wd11AllocCount--;
    free( pucObjPtr );
    if (dump) {
#ifdef sapdbwa_MEMCHECK
        _CrtDumpMemoryLeaks();
#endif        
    }; /* if */
}

==> sapdb-source-7.4.03.32.tgz: V74_03_32/SAPDB_ORG/sys/src/wd/vwd10mem.c <==
/*!**********************************************************************

  module: vwd10mem.c

  -----------------------------------------------------------------------

  
  responsible:  Holger Bischoff
				Markus Oezgen

  special area: WebAgent

  description:  Memory routines for WebAgent

  see also:

  -----------------------------------------------------------------------

  copyright:                Copyright by SAP AG, 1999



    ========== licence begin LGPL
    Copyright (C) 2000 SAP AG

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    ========== licence end

************************************************************************/

#include <stdlib.h>

#ifdef WIN32
#define _DEBUG
#include <crtdbg.h>
#endif

#include "geo102.h"
#include "hwd10mem.h"

static wd11AllocCount = 0;

void sapdbwa_allocat( size_t              lSize,
					  sapdbwa_UInt1		**ppucObjPtr,
					  tsp00_BoolAddr      pbOk		)
{
    wd11AllocCount++;
    *ppucObjPtr = malloc( lSize );
    *pbOk = (tsp00_Bool) (ppucObjPtr != NULL);
}


void sapdbwa_reallocat( size_t            lSize,
						sapdbwa_UInt1	**ppucObjPtr,
						tsp00_BoolAddr    pbOk		)
{
    *ppucObjPtr = realloc( *ppucObjPtr, lSize );
    *pbOk = (tsp00_Bool) (ppucObjPtr != NULL);
}


void sapdbwa_free( sapdbwa_UInt1*  pucObjPtr )
{
    tsp00_Bool dump = (pucObjPtr == (sapdbwa_UInt1*) 17);
    
    wd11AllocCount--;
    free( pucObjPtr );
    if (dump) {
#ifdef sapdbwa_MEMCHECK
        _CrtDumpMemoryLeaks();
#endif        
    }; /* if */
}
